manifest_url

Function manifest_url 

fn manifest_url(extension: &str, version: Option<&str>) -> String
Builds the manifest URL for an extension, optionally pinned to a version.

Strips tempo- and v prefixes from the extension name and version respectively to avoid double-prefixing (e.g. tempo add tempo-wallet resolves correctly).